@@ -35,6 +35,8 @@ sub _start {
       server   => $server,
       nick     => $nickname,
       username => $username,
+      port     => 6697,
+      ssl      => 1,
     )
   );
   $heap->irc->connect;
