@@ -1,5 +1,5 @@
 package POEx::IRC::Client::Lite;
-$POEx::IRC::Client::Lite::VERSION = '0.003001';
+$POEx::IRC::Client::Lite::VERSION = '0.004001';
 use strictures 2;
 
 use Carp 'confess';
@@ -57,7 +57,7 @@ has bindaddr => (
   isa       => Defined,
   writer    => 'set_bindaddr',
   predicate => 'has_bindaddr',
-  default   => sub {
+  builder   => sub {
     my ($self) = @_;
     $self->has_ipv6 && $self->ipv6 ? 
       '::0' : '0.0.0.0'
@@ -70,7 +70,7 @@ has ipv6 => (
   isa       => Bool,
   writer    => 'set_ipv6',
   predicate => 'has_ipv6',
-  default   => sub { 0 },
+  builder   => sub { 0 },
 );
 
 has ssl => (
@@ -78,7 +78,15 @@ has ssl => (
   is        => 'ro',
   isa       => Bool,
   writer    => 'set_ssl',
-  default   => sub { 0 },
+  builder   => sub { 0 },
+);
+
+has ssl_opts => (
+  lazy      => 1,
+  is        => 'ro',
+  isa       => Maybe[ArrayRef],
+  writer    => 'set_ssl_opts',
+  builder   => sub { undef },
 );
 
 has pass => (
@@ -88,7 +96,7 @@ has pass => (
   writer    => 'set_pass',
   predicate => 'has_pass',
   clearer   => 'clear_pass',
-  default   => sub { '' },
+  builder   => sub { '' },
 );
 
 has port => (
@@ -97,7 +105,7 @@ has port => (
   isa       => Num,
   writer    => 'set_port',
   predicate => 'has_port',
-  default   => sub { 6667 },
+  builder   => sub { 6667 },
 );
 
 has realname => (
@@ -106,7 +114,7 @@ has realname => (
   isa       => Str,
   writer    => 'set_realname',
   predicate => 'has_realname',
-  default   => sub { __PACKAGE__ },
+  builder   => sub { __PACKAGE__ },
 );
 
 has reconnect => (
@@ -114,7 +122,7 @@ has reconnect => (
   is        => 'ro',
   isa       => Num,
   writer    => 'set_reconnect',
-  default   => sub { 120 },
+  builder   => sub { 120 },
 );
 
 has username => (
@@ -123,7 +131,7 @@ has username => (
   isa       => Str,
   writer    => 'set_username',
   predicate => 'has_username',
-  default   => sub { 'ircplug' },
+  builder   => sub { 'ircplug' },
 );
 
 ### Typically internal:
@@ -183,7 +191,10 @@ sub BUILD {
 
 sub _emitter_started {
   my ($kernel, $self) = @_[KERNEL, OBJECT];
-  $kernel->post( $self->backend->spawn->session_id => 'register' );
+  $self->backend->spawn(
+    ( $self->ssl_opts ? (ssl_opts => $self->ssl_opts) : () ),
+  );
+  $kernel->post( $self->backend->session_id => 'register' );
 }
 
 sub stop {
@@ -474,7 +485,7 @@ sub _mode {
     ##       don't really want to parse/store isupport here
     ##       (stateful subclasses should worry about it)
     for my $set ($mode->split_mode_set(4)) {
-      $self->mode( $target, $set->mode_string )
+      $self->call( mode => $target, $set->mode_string )
     }
     return $self
   }
@@ -635,6 +646,14 @@ Boolean value indicating whether to (attempt to) connect via SSL.
 
 Requires L<POE::Component::SSLify>.
 
+=item ssl_opts
+
+An C<ARRAY> containing SSL options passed along to L<POE::Component::SSLify>
+via L<POEx::IRC::Backend>; see L<POE::Component::SSLify> & L<Net::SSLeay>.
+
+Not required for basic SSL operation; setting L</ssl> to a true value should
+work for most users.
+
 =item reconnect
 
 Reconnection attempt delay, in seconds.
